==> aws-cdk.integ-tests-alpha-2.21.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_integ_tests_alpha_IntegTestCaseProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.stacks))
            require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_Stack(p.stacks);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_integ_tests_alpha_IntegTestCase(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_integ_tests_alpha_IntegTestCaseProps, _aws_cdk_integ_tests_alpha_IntegTestCase };

==> aws-cdk.integ-tests-alpha-2.23.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_integ_tests_alpha_IntegTestCaseProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.stacks))
            require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_Stack(p.stacks);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_integ_tests_alpha_IntegTestCase(p) {
}
function _aws_cdk_integ_tests_alpha_IntegTestProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.testCases))
            _aws_cdk_integ_tests_alpha_IntegTestCase(p.testCases);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_integ_tests_alpha_IntegTest(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_integ_tests_alpha_IntegTestCaseProps, _aws_cdk_integ_tests_alpha_IntegTestCase, _aws_cdk_integ_tests_alpha_IntegTestProps, _aws_cdk_integ_tests_alpha_IntegTest };
